@@ -71,6 +71,9 @@ static dbi_inst dbi_instance = NULL;
 static const gchar* suitename = "/backend/dbi";
 void test_suite_gnc_backend_dbi (void);
 
+static std::string mysql_url{};
+static std::string pgsql_url{};
+
 using StrVec = std::vector<std::string>;
 
 typedef struct
@@ -361,7 +364,7 @@ test_conn_index_functions (QofBackend* qof_be)
     {
         const char* errmsg;
         conn->provider()->drop_index (dbi_be->conn, index);
-        g_assert (DBI_ERROR_NONE == dbi_conn_error (conn->conn(), &errmsg));
+        g_assert_true (DBI_ERROR_NONE == dbi_conn_error (conn->conn(), &errmsg));
     }
 
 }
@@ -388,23 +391,23 @@ test_dbi_store_and_reload (Fixture* fixture, gconstpointer pData)
     auto book2{qof_book_new()};
     auto session_2 = qof_session_new (book2);
     qof_session_begin (session_2, url, SESSION_NEW_OVERWRITE);
-    g_assert (session_2 != NULL);
+    g_assert_true (session_2 != NULL);
     g_assert_cmpint (qof_session_get_error (session_2), == , ERR_BACKEND_NO_ERR);
     qof_session_swap_data (fixture->session, session_2);
     qof_book_mark_session_dirty (qof_session_get_book (session_2));
     qof_session_save (session_2, NULL);
-    g_assert (session_2 != NULL);
+    g_assert_true (session_2 != NULL);
     g_assert_cmpint (qof_session_get_error (session_2), == , ERR_BACKEND_NO_ERR);
 
     // Reload the session data
     auto book3{qof_book_new()};
     auto session_3 = qof_session_new (book3);
-    g_assert (session_3 != NULL);
+    g_assert_true (session_3 != NULL);
     qof_session_begin (session_3, url, SESSION_READ_ONLY);
-    g_assert (session_3 != NULL);
+    g_assert_true (session_3 != NULL);
     g_assert_cmpint (qof_session_get_error (session_3), == , ERR_BACKEND_NO_ERR);
     qof_session_load (session_3, NULL);
-    g_assert (session_3 != NULL);
+    g_assert_true (session_3 != NULL);
     g_assert_cmpint (qof_session_get_error (session_3), == , ERR_BACKEND_NO_ERR);
     // Compare with the original data
     compare_books (qof_session_get_book (session_2),
@@ -447,7 +450,7 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
         g_warning ("Session Error: %d, %s", qof_session_get_error (session_1),
                    qof_session_get_error_message (session_1));
         g_test_message ("DB Session Creation Failed");
-        g_assert (FALSE);
+        g_assert_true (FALSE);
         goto cleanup;
     }
     qof_session_swap_data (fixture->session, session_1);
@@ -460,7 +463,7 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
         g_warning ("Session Error: %s",
                    qof_session_get_error_message (session_1));
         g_test_message ("DB Session Safe Save Failed");
-        g_assert (FALSE);
+        g_assert_true (FALSE);
         goto cleanup;
     }
     /* Destroy the session and reload it */
@@ -473,7 +476,7 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
         g_warning ("Session Error: %d, %s", qof_session_get_error (session_2),
                    qof_session_get_error_message (session_2));
         g_test_message ("DB Session re-creation Failed");
-        g_assert (FALSE);
+        g_assert_true (FALSE);
         goto cleanup;
     }
     qof_session_load (session_2, NULL);
@@ -520,7 +523,7 @@ test_dbi_version_control (Fixture* fixture, gconstpointer pData)
         g_warning ("Session Error: %d, %s", qof_session_get_error (sess),
                    qof_session_get_error_message (sess));
         g_test_message ("DB Session Creation Failed");
-        g_assert (FALSE);
+        g_assert_true (FALSE);
         goto cleanup;
     }
     qof_session_swap_data (fixture->session, sess);
@@ -663,19 +666,22 @@ test_suite_gnc_backend_dbi (void)
     {
         drivers.push_back(dbi_driver_get_name (driver));
     }
+    mysql_url.append(getenv("TEST_MYSQL_URL") ? getenv("TEST_MYSQL_URL") : "");
+    pgsql_url.append(getenv("TEST_PGSQL_URL") ? getenv("TEST_PGSQL_URL") : "");
+
     for (auto name : drivers)
     {
         if (name == "sqlite3")
             create_dbi_test_suite ("sqlite3", "sqlite3");
-        if (strlen (TEST_MYSQL_URL) > 0 && name == "mysql")
-            create_dbi_test_suite ("mysql", TEST_MYSQL_URL);
-        if (strlen (TEST_PGSQL_URL) > 0 && name == "pgsql")
+        if (!mysql_url.empty() && name == "mysql")
+            create_dbi_test_suite ("mysql", mysql_url.c_str());
+        if (!pgsql_url.empty() && name == "pgsql")
         {
             g_setenv ("PGOPTIONS", "-c client_min_messages=WARNING", FALSE);
-            create_dbi_test_suite ("postgres", TEST_PGSQL_URL);
+            create_dbi_test_suite ("postgres", pgsql_url.c_str());
         }
     }
 
-    GNC_TEST_ADD_FUNC( suitename, "adjust sql options string localtime", 
+    GNC_TEST_ADD_FUNC( suitename, "adjust sql options string localtime",
         test_adjust_sql_options_string );
 }
