@@ -1,7 +1,7 @@
 
 /* Test file created by Linas Vepstas <linas@linas.org>
  * Review operation of the gnc-numeric tools by verifying results
- * of vairous operations.
+ * of various operations.
  *
  * June 2004
  */
@@ -21,17 +21,14 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  *  02110-1301, USA.
  */
+#include <glib.h>
 
-extern "C"
-{
 #include <config.h>
 #include <ctype.h>
-#include <glib.h>
 #include "cashobjects.h"
 #include "test-stuff.h"
 #include "test-engine-stuff.h"
 #include "gnc-numeric.h"
-}
 
 #define NREPS 2
 
@@ -243,7 +240,7 @@ check_equality_operator (void)
         check_unary_op (gnc_numeric_equal,
                         val, mval, mval, "expected %s = %s");
 
-        /* Certain modulo's should be very cleary un-equal; this
+        /* Certain modulo's should be very clearly un-equal; this
          * helps stop funky modulo-64 aliasing in compares that
          * might creep in. */
         mval.denom >>= 1;
@@ -548,8 +545,8 @@ check_add_subtract (void)
 static const gint64 pten[] = { 1, 10, 100, 1000, 10000, 100000, 1000000,
 			       10000000, 100000000, 1000000000, 10000000000,
 			       100000000000, 1000000000000, 10000000000000,
-			       100000000000000, 10000000000000000,
-			       100000000000000000, 1000000000000000000};
+			       100000000000000, 1000000000000000,
+			       10000000000000000, 100000000000000000};
 #define POWTEN_OVERFLOW -5
 
 static inline gint64
@@ -720,7 +717,7 @@ check_mult_div (void)
                      a, b, "expected %s got %s = %s * %s for div 100th's");
 
     /* Check for math with 2^63 < num*num < 2^64 which previously failed
-     * see http://bugzilla.gnome.org/show_bug.cgi?id=144980
+     * see https://bugs.gnucash.org/show_bug.cgi?id=144980
      */
     v = 1000000;
     a = gnc_numeric_create(1 * v, v);
@@ -797,7 +794,7 @@ check_mult_div (void)
      * 64-bit quantity.  This can be seen from
      * the factorization into primes:
      * 1173888083434299 = 3 * 2283317 * 171371749
-     * (yes, thats a seven and a nine digit prime)
+     * (yes, that's a seven and a nine digit prime)
      * 2222554708930978 = 2 * 1111277354465489
      * (yes, that's a sixteen-digit prime number)
      * 93773 = 79*1187
